@@ -19,14 +19,16 @@ fn scan(build: &mut Build, path: &str, suffix: &str) {
 fn main() {
     let mut c = cc::Build::new();
     c.warnings(false);
-    c.shared_flag(true);
-    //c.cargo_metadata(false);
+    c.cargo_metadata(false);
 
     scan(&mut c, "./device-detection-cxx/src/", ".c");
     scan(&mut c, "./device-detection-cxx/src/hash/", ".c");
     scan(&mut c, "./device-detection-cxx/src/common-cxx/", ".c");
 
-    c.compile("c.so");
+    c.compile("51c");
+
+    // see https://github.com/rust-lang/rust/issues/38095, otherwise "multiple definition" error
+    println!("cargo:rustc-link-lib=dylib=51c");
 
     let source_files = vec!["src/shim/mod.rs"];
 
@@ -38,11 +40,11 @@ fn main() {
     scan(&mut build, "./device-detection-cxx/src/hash/", ".cpp");
     scan(&mut build, "./device-detection-cxx/src/common-cxx/", ".cpp");
 
+    let out = PathBuf::from(env::var("OUT_DIR").unwrap());
+
     build.include(".");
     build.flag("-std=c++11");
-    build.compile("cxxbridge");
-
-    let out = PathBuf::from(env::var("OUT_DIR").unwrap());
+    build.compile("51c++");
 
     // prevent git submodule from being packaged
     fs::remove_dir_all(out.join("device-detection-cxx")).unwrap();
